queue

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2022 License: Apache-2.0 Imports: 7 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dequeue added in v0.4.0

func Dequeue[T any](q swarm.Queue, category ...string) (<-chan *swarm.Msg[T], chan<- *swarm.Msg[T])

Dequeue creates channels to receive Golang structs and send acknowledgement

func Enqueue added in v0.4.0

func Enqueue[T any](q swarm.Queue, category ...string) (chan<- T, <-chan T)

Enqueue creates channels to enqueue Golang structs and receive dead-letters

func EnqueueSync added in v0.4.0

func EnqueueSync[T any](q swarm.Queue, msg T) error

EnqueueSync synchronously enqueue message

Types

This section is empty.

Directories

Path Synopsis

Jump to