bytes

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 3, 2022 License: Apache-2.0 Imports: 4 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dequeue

func Dequeue(q swarm.Queue, cat string) (<-chan *swarm.Msg[[]byte], chan<- *swarm.Msg[[]byte])

DequeueBytes creates channels to receive binary messages and send acknowledgement

func Enqueue

func Enqueue(q swarm.Queue, cat string) (chan<- []byte, <-chan []byte)

Enqueue creates channels to enqueue binary messages and receive dead-letters

Types

This section is empty.

Jump to