Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Msg ¶
type Msg interface {
Bytes() []byte
}
Msg type is an abstract container for octet stream exchange via channels
ch <- swarm.Bytes("some message")
...
for msg := range ch {
msg.Bytes()
}
type Queue ¶
type Queue interface {
/*
Creates endpoints to receive messages and acknowledge its consumption.
*/
Recv(Category) (<-chan Msg, chan<- Msg)
/*
Creates endpoints to send messages and receive errors.
*/
Send(Category) (chan<- Msg, <-chan Msg)
}
Queue ...
Directories
¶
| Path | Synopsis |
|---|---|
|
broker
|
|
|
embedded
module
|
|
|
eventbridge
module
|
|
|
eventddb
module
|
|
|
events3
module
|
|
|
eventsqs
module
|
|
|
sqs
module
|
|
|
websocket
module
|
|
|
example
|
|
|
eventbridge/recv
command
|
|
|
eventbridge/send
command
|
|
|
sqs/recv
command
|
|
|
sqs/send
command
|
|
|
qtest
module
|
|
Click to show internal directories.
Click to hide internal directories.