Documentation
¶
Index ¶
- func Dequeue[T any](q swarm.Queue, category ...string) (<-chan *swarm.Msg[T], chan<- *swarm.Msg[T])
- func DequeueBytes(q swarm.Queue, cat string) (<-chan *swarm.Msg[[]byte], chan<- *swarm.Msg[[]byte])
- func Enqueue[T any](q swarm.Queue, category ...string) (chan<- T, <-chan T)
- func EnqueueBytes(q swarm.Queue, cat string) (chan<- []byte, <-chan []byte)
- func EnqueueSync[T any](q swarm.Queue, msg T) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dequeue ¶ added in v0.4.0
Dequeue creates channels to receive Golang structs and send acknowledgement
func DequeueBytes ¶ added in v0.4.0
DequeueBytes creates channels to receive binary messages and send acknowledgement
func Enqueue ¶ added in v0.4.0
Enqueue creates channels to enqueue Golang structs and receive dead-letters
func EnqueueBytes ¶ added in v0.4.0
EnqueueBytes creates channels to enqueue binary messages and receive dead-letters
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.