Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Adapter ¶
type Adapter struct {
System swarm.System
ID string
Policy *Policy
// contains filtered or unexported fields
}
Adapter to queueing systems
func (*Adapter) ConfIO ¶
ConfIO create go routine to adapt async i/o over Golang channel to synchronous calls of queueing system interface
type Bag ¶
type Bag struct {
// message attributes
Target string
Source string
Category swarm.Category
// message payload
Object swarm.Msg
//
StdErr chan<- swarm.Msg
}
Bag is a product type of message and its attributes
type Msg ¶
Msg type defines external ingress message. It containers both payload and receipt to acknowledge
type Queue ¶
type Queue struct {
sync.Mutex
System swarm.System
ID string
// contains filtered or unexported fields
}
Queue ...
func New ¶
func New( sys swarm.System, id string, recv func() (<-chan *Bag, chan<- *Bag), send func() chan<- *Bag, ) *Queue
New creates
Click to show internal directories.
Click to hide internal directories.